@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.60 2011/07/20 07:59:28 dcoppa Exp $
+# $OpenBSD: Quirks.pm,v 1.66 2012/02/06 22:07:09 espie Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -249,7 +249,36 @@ my $stem_extensions = {
 	'wqy-zenhei-ttf' => 'zh-wqy-zenhei-ttf',
 	'wqy-bitmapfont' => 'zh-wqy-bitmapfont',
 	'ptsans' => 'ru-ptsans',
-	'py-zeya' => 'zeya'
+	'py-zeya' => 'zeya',
+# 5.1
+	'php5-mapscript' => 'php-mapscript',
+	'libusb' => 'libusb-compat',
+	'pecl-pcntl' => 'php-pcntl',
+	'distribute' => 'py3-distribute',
+	'aspell6-ar' => 'aspell-ar',
+	'aspell6-bg' => 'aspell-bg',
+	'aspell6-ca' => 'aspell-ca',
+	'aspell6-cs' => 'aspell-cs',
+	'aspell5-da' => 'aspell-da',
+	'aspell6-de' => 'aspell-de',
+	'aspell6-eo' => 'aspell-eo',
+	'aspell6-es' => 'aspell-es',
+	'aspell6-fa' => 'aspell-fa',
+	'aspell5-fo' => 'aspell-fo',
+	'aspell5-ga' => 'aspell-ga',
+	'aspell6-gl' => 'aspell-gl',
+	'aspell6-he' => 'aspell-he',
+	'aspell5-id' => 'aspell-id',
+	'aspell6-it' => 'aspell-it',
+	'aspell6-lt' => 'aspell-lt',
+	'aspell6-pl' => 'aspell-pl',
+	'aspell5-ro' => 'aspell-ro',
+	'aspell6-ru' => 'aspell-ru',
+	'aspell6-sk' => 'aspell-sk',
+	'aspell6-sr' => 'aspell-sr',
+	'aspell5-tn' => 'aspell-tn',
+	'aspell6-uk' => 'aspell-uk',
+	'vte-ptyhelper' => 'vte',
 };
 
 # ->is_base_system($handle, $state):
